@@ -242,12 +242,11 @@ CFG_BOOL_KEYS = frozenset(
 
 
 def cfg2dict(cfg: str | Path | dict | SimpleNamespace) -> dict:
-    """
-    Convert a configuration object to a dictionary.
+    """Convert a configuration object to a dictionary.
 
     Args:
-        cfg (str | Path | dict | SimpleNamespace): Configuration object to be converted. Can be a file path,
-            a string, a dictionary, or a SimpleNamespace object.
+        cfg (str | Path | dict | SimpleNamespace): Configuration object to be converted. Can be a file path, a string, a
+            dictionary, or a SimpleNamespace object.
 
     Returns:
         (dict): Configuration object in dictionary format.
@@ -279,8 +278,7 @@ def cfg2dict(cfg: str | Path | dict | SimpleNamespace) -> dict:
 def get_cfg(
     cfg: str | Path | dict | SimpleNamespace = DEFAULT_CFG_DICT, overrides: dict | None = None
 ) -> SimpleNamespace:
-    """
-    Load and merge configuration data from a file or dictionary, with optional overrides.
+    """Load and merge configuration data from a file or dictionary, with optional overrides.
 
     Args:
         cfg (str | Path | dict | SimpleNamespace): Configuration data source. Can be a file path, dictionary, or
@@ -327,11 +325,10 @@ def get_cfg(
 
 
 def check_cfg(cfg: dict, hard: bool = True) -> None:
-    """
-    Check configuration argument types and values for the Ultralytics library.
+    """Check configuration argument types and values for the Ultralytics library.
 
-    This function validates the types and values of configuration arguments, ensuring correctness and converting
-    them if necessary. It checks for specific key types defined in global variables such as `CFG_FLOAT_KEYS`,
+    This function validates the types and values of configuration arguments, ensuring correctness and converting them if
+    necessary. It checks for specific key types defined in global variables such as `CFG_FLOAT_KEYS`,
     `CFG_FRACTION_KEYS`, `CFG_INT_KEYS`, and `CFG_BOOL_KEYS`.
 
     Args:
@@ -389,14 +386,13 @@ def check_cfg(cfg: dict, hard: bool = True) -> None:
 
 
 def get_save_dir(args: SimpleNamespace, name: str | None = None) -> Path:
-    """
-    Return the directory path for saving outputs, derived from arguments or default settings.
+    """Return the directory path for saving outputs, derived from arguments or default settings.
 
     Args:
-        args (SimpleNamespace): Namespace object containing configurations such as 'project', 'name', 'task',
-            'mode', and 'save_dir'.
-        name (str | None): Optional name for the output directory. If not provided, it defaults to 'args.name'
-            or the 'args.mode'.
+        args (SimpleNamespace): Namespace object containing configurations such as 'project', 'name', 'task', 'mode',
+            and 'save_dir'.
+        name (str | None): Optional name for the output directory. If not provided, it defaults to 'args.name' or the
+            'args.mode'.
 
     Returns:
         (Path): Directory path where outputs should be saved.
@@ -421,8 +417,7 @@ def get_save_dir(args: SimpleNamespace, name: str | None = None) -> Path:
 
 
 def _handle_deprecation(custom: dict) -> dict:
-    """
-    Handle deprecated configuration keys by mapping them to current equivalents with deprecation warnings.
+    """Handle deprecated configuration keys by mapping them to current equivalents with deprecation warnings.
 
     Args:
         custom (dict): Configuration dictionary potentially containing deprecated keys.
@@ -465,8 +460,7 @@ def _handle_deprecation(custom: dict) -> dict:
 
 
 def check_dict_alignment(base: dict, custom: dict, e: Exception | None = None) -> None:
-    """
-    Check alignment between custom and base configuration dictionaries, handling deprecated keys and providing error
+    """Check alignment between custom and base configuration dictionaries, handling deprecated keys and providing error
     messages for mismatched keys.
 
     Args:
@@ -505,8 +499,7 @@ def check_dict_alignment(base: dict, custom: dict, e: Exception | None = None) -
 
 
 def merge_equals_args(args: list[str]) -> list[str]:
-    """
-    Merge arguments around isolated '=' in a list of strings and join fragments with brackets.
+    """Merge arguments around isolated '=' in a list of strings and join fragments with brackets.
 
     This function handles the following cases:
         1. ['arg', '=', 'val'] becomes ['arg=val']
@@ -518,7 +511,8 @@ def merge_equals_args(args: list[str]) -> list[str]:
         args (list[str]): A list of strings where each element represents an argument or fragment.
 
     Returns:
-        (list[str]): A list of strings where the arguments around isolated '=' are merged and fragments with brackets are joined.
+        (list[str]): A list of strings where the arguments around isolated '=' are merged and fragments with brackets
+            are joined.
 
     Examples:
         >>> args = ["arg1", "=", "value", "arg2=", "value2", "arg3", "=value3", "imgsz=[3,", "640,", "640]"]
@@ -564,15 +558,14 @@ def merge_equals_args(args: list[str]) -> list[str]:
 
 
 def handle_yolo_hub(args: list[str]) -> None:
-    """
-    Handle Ultralytics HUB command-line interface (CLI) commands for authentication.
+    """Handle Ultralytics HUB command-line interface (CLI) commands for authentication.
 
     This function processes Ultralytics HUB CLI commands such as login and logout. It should be called when executing a
     script with arguments related to HUB authentication.
 
     Args:
-        args (list[str]): A list of command line arguments. The first argument should be either 'login'
-            or 'logout'. For 'login', an optional second argument can be the API key.
+        args (list[str]): A list of command line arguments. The first argument should be either 'login' or 'logout'. For
+            'login', an optional second argument can be the API key.
 
     Examples:
         $ yolo login YOUR_API_KEY
@@ -594,8 +587,7 @@ def handle_yolo_hub(args: list[str]) -> None:
 
 
 def handle_yolo_settings(args: list[str]) -> None:
-    """
-    Handle YOLO settings command-line interface (CLI) commands.
+    """Handle YOLO settings command-line interface (CLI) commands.
 
     This function processes YOLO settings CLI commands such as reset and updating individual settings. It should be
     called when executing a script with arguments related to YOLO settings management.
@@ -637,13 +629,10 @@ def handle_yolo_settings(args: list[str]) -> None:
 
 
 def handle_yolo_solutions(args: list[str]) -> None:
-    """
-    Process YOLO solutions arguments and run the specified computer vision solutions pipeline.
+    """Process YOLO solutions arguments and run the specified computer vision solutions pipeline.
 
     Args:
-        args (list[str]): Command-line arguments for configuring and running the Ultralytics YOLO
-            solutions: https://docs.ultralytics.com/solutions/, It can include solution name, source,
-            and other configuration parameters.
+        args (list[str]): Command-line arguments for configuring and running the Ultralytics YOLO solutions.
 
     Examples:
         Run people counting solution with default settings:
@@ -749,8 +738,7 @@ def handle_yolo_solutions(args: list[str]) -> None:
 
 
 def parse_key_value_pair(pair: str = "key=value") -> tuple:
-    """
-    Parse a key-value pair string into separate key and value components.
+    """Parse a key-value pair string into separate key and value components.
 
     Args:
         pair (str): A string containing a key-value pair in the format "key=value".
@@ -783,8 +771,7 @@ def parse_key_value_pair(pair: str = "key=value") -> tuple:
 
 
 def smart_value(v: str) -> Any:
-    """
-    Convert a string representation of a value to its appropriate Python type.
+    """Convert a string representation of a value to its appropriate Python type.
 
     This function attempts to convert a given string into a Python object of the most appropriate type. It handles
     conversions to None, bool, int, float, and other types that can be evaluated safely.
@@ -793,8 +780,8 @@ def smart_value(v: str) -> Any:
         v (str): The string representation of the value to be converted.
 
     Returns:
-        (Any): The converted value. The type can be None, bool, int, float, or the original string if no conversion
-            is applicable.
+        (Any): The converted value. The type can be None, bool, int, float, or the original string if no conversion is
+            applicable.
 
     Examples:
         >>> smart_value("42")
@@ -828,11 +815,10 @@ def smart_value(v: str) -> Any:
 
 
 def entrypoint(debug: str = "") -> None:
-    """
-    Ultralytics entrypoint function for parsing and executing command-line arguments.
+    """Ultralytics entrypoint function for parsing and executing command-line arguments.
 
-    This function serves as the main entry point for the Ultralytics CLI, parsing command-line arguments and
-    executing the corresponding tasks such as training, validation, prediction, exporting models, and more.
+    This function serves as the main entry point for the Ultralytics CLI, parsing command-line arguments and executing
+    the corresponding tasks such as training, validation, prediction, exporting models, and more.
 
     Args:
         debug (str): Space-separated string of command-line arguments for debugging purposes.
@@ -1001,12 +987,11 @@ def entrypoint(debug: str = "") -> None:
 
 # Special modes --------------------------------------------------------------------------------------------------------
 def copy_default_cfg() -> None:
-    """
-    Copy the default configuration file and create a new one with '_copy' appended to its name.
+    """Copy the default configuration file and create a new one with '_copy' appended to its name.
 
-    This function duplicates the existing default configuration file (DEFAULT_CFG_PATH) and saves it
-    with '_copy' appended to its name in the current working directory. It provides a convenient way
-    to create a custom configuration file based on the default settings.
+    This function duplicates the existing default configuration file (DEFAULT_CFG_PATH) and saves it with '_copy'
+    appended to its name in the current working directory. It provides a convenient way to create a custom configuration
+    file based on the default settings.
 
     Examples:
         >>> copy_default_cfg()
