@@ -5,25 +5,23 @@ from .tasks import (
     ClassificationModel,
     DetectionModel,
     SegmentationModel,
-    attempt_load_one_weight,
-    attempt_load_weights,
     guess_model_scale,
     guess_model_task,
+    load_checkpoint,
     parse_model,
     torch_safe_load,
     yaml_model_load,
 )
 
 __all__ = (
-    "attempt_load_one_weight",
-    "attempt_load_weights",
-    "parse_model",
-    "yaml_model_load",
-    "guess_model_task",
-    "guess_model_scale",
-    "torch_safe_load",
+    "BaseModel",
+    "ClassificationModel",
     "DetectionModel",
     "SegmentationModel",
-    "ClassificationModel",
-    "BaseModel",
+    "guess_model_scale",
+    "guess_model_task",
+    "load_checkpoint",
+    "parse_model",
+    "torch_safe_load",
+    "yaml_model_load",
 )
