@@ -16,13 +16,12 @@ def is_noninteractive_console() -> bool:
 
 
 class TQDM:
-    """
-    Lightweight zero-dependency progress bar for Ultralytics.
+    """Lightweight zero-dependency progress bar for Ultralytics.
 
-    Provides clean, rich-style progress bars suitable for various environments including Weights & Biases,
-    console outputs, and other logging systems. Features zero external dependencies, clean single-line output,
-    rich-style progress bars with Unicode block characters, context manager support, iterator protocol support,
-    and dynamic description updates.
+    Provides clean, rich-style progress bars suitable for various environments including Weights & Biases, console
+    outputs, and other logging systems. Features zero external dependencies, clean single-line output, rich-style
+    progress bars with Unicode block characters, context manager support, iterator protocol support, and dynamic
+    description updates.
 
     Attributes:
         iterable (object): Iterable to wrap with progress bar.
@@ -94,8 +93,7 @@ class TQDM:
         initial: int = 0,
         **kwargs,
     ) -> None:
-        """
-        Initialize the TQDM progress bar with specified configuration options.
+        """Initialize the TQDM progress bar with specified configuration options.
 
         Args:
             iterable (object, optional): Iterable to wrap with progress bar.
